/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 51 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 55 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 58 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 61 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 102 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 127 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 130 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 133 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 156 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 726 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 795 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 425 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 174 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 199 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 220 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 247 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 264 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 267 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 270 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 273 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 276 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 279 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qwindow.sip"
#include <qwindow.h>
#line 282 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 195 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 285 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 288 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 302 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 291 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 294 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 297 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 300 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 303 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 412 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 306 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 309 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 312 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qscreen.sip"
#include <qscreen.h>
#line 315 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 318 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 321 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qicon.sip"
#include <qicon.h>
#line 324 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 327 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 330 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 333 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 336 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurface.sip"
#include <qsurface.h>
#line 339 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 344 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 347 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 350 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 353 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 356 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 359 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 362 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 365 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 368 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 371 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 374 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 377 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 380 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DGraph.cpp"


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_addInputHandler, "addInputHandler(self, inputHandler: QAbstract3DInputHandler|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addInputHandler(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addInputHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DInputHandler* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DInputHandler, &a0))
        {
            sipCpp->addInputHandler(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_addInputHandler, doc_QtDataVisualization_QAbstract3DGraph_addInputHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_releaseInputHandler, "releaseInputHandler(self, inputHandler: QAbstract3DInputHandler|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseInputHandler(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseInputHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DInputHandler* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DInputHandler, &a0))
        {
            sipCpp->releaseInputHandler(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_releaseInputHandler, doc_QtDataVisualization_QAbstract3DGraph_releaseInputHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler, "setActiveInputHandler(self, inputHandler: QAbstract3DInputHandler|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DInputHandler* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DInputHandler, &a0))
        {
            sipCpp->setActiveInputHandler(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setActiveInputHandler, doc_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_inputHandlers, "inputHandlers(self) -> list[QAbstract3DInputHandler]");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_inputHandlers(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_inputHandlers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            QList< ::QtDataVisualization::QAbstract3DInputHandler*>*sipRes;

            sipRes = new QList< ::QtDataVisualization::QAbstract3DInputHandler*>(sipCpp->inputHandlers());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtDataVisualization_QAbstract3DInputHandler, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_inputHandlers, doc_QtDataVisualization_QAbstract3DGraph_inputHandlers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_addTheme, "addTheme(self, theme: Q3DTheme|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addTheme(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_Q3DTheme, &a0))
        {
            sipCpp->addTheme(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_addTheme, doc_QtDataVisualization_QAbstract3DGraph_addTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_releaseTheme, "releaseTheme(self, theme: Q3DTheme|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseTheme(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_Q3DTheme, &a0))
        {
            sipCpp->releaseTheme(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_releaseTheme, doc_QtDataVisualization_QAbstract3DGraph_releaseTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setActiveTheme, "setActiveTheme(self, theme: Q3DTheme|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setActiveTheme(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setActiveTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_Q3DTheme, &a0))
        {
            sipCpp->setActiveTheme(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setActiveTheme, doc_QtDataVisualization_QAbstract3DGraph_setActiveTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_activeTheme, "activeTheme(self) -> Q3DTheme|None");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_activeTheme(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_activeTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::Q3DTheme*sipRes;

            sipRes = sipCpp->activeTheme();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_Q3DTheme, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_activeTheme, doc_QtDataVisualization_QAbstract3DGraph_activeTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_themes, "themes(self) -> list[Q3DTheme]");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_themes(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_themes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            QList< ::QtDataVisualization::Q3DTheme*>*sipRes;

            sipRes = new QList< ::QtDataVisualization::Q3DTheme*>(sipCpp->themes());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtDataVisualization_Q3DTheme, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_themes, doc_QtDataVisualization_QAbstract3DGraph_themes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setSelectionMode, "setSelectionMode(self, mode: QAbstract3DGraph.SelectionFlags|QAbstract3DGraph.SelectionFlag)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setSelectionMode(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setSelectionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph::SelectionFlags* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, &a0, &a0State))
        {
            sipCpp->setSelectionMode(*a0);
            sipReleaseType(a0, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setSelectionMode, doc_QtDataVisualization_QAbstract3DGraph_setSelectionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectionMode, "selectionMode(self) -> QAbstract3DGraph.SelectionFlags");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectionMode(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DGraph::SelectionFlags*sipRes;

            sipRes = new ::QtDataVisualization::QAbstract3DGraph::SelectionFlags(sipCpp->selectionMode());

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectionMode, doc_QtDataVisualization_QAbstract3DGraph_selectionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setShadowQuality, "setShadowQuality(self, quality: QAbstract3DGraph.ShadowQuality)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setShadowQuality(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setShadowQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph::ShadowQuality a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DGraph_ShadowQuality, &a0))
        {
            sipCpp->setShadowQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setShadowQuality, doc_QtDataVisualization_QAbstract3DGraph_setShadowQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_shadowQuality, "shadowQuality(self) -> QAbstract3DGraph.ShadowQuality");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_shadowQuality(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_shadowQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DGraph::ShadowQuality sipRes;

            sipRes = sipCpp->shadowQuality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DGraph_ShadowQuality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_shadowQuality, doc_QtDataVisualization_QAbstract3DGraph_shadowQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_scene, "scene(self) -> Q3DScene|None");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_scene(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_scene(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::Q3DScene*sipRes;

            sipRes = sipCpp->scene();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_Q3DScene, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_scene, doc_QtDataVisualization_QAbstract3DGraph_scene);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_clearSelection, "clearSelection(self)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_clearSelection(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_clearSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            sipCpp->clearSelection();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_clearSelection, doc_QtDataVisualization_QAbstract3DGraph_clearSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_activeInputHandler, "activeInputHandler(self) -> QAbstract3DInputHandler|None");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_activeInputHandler(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_activeInputHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DInputHandler*sipRes;

            sipRes = sipCpp->activeInputHandler();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QAbstract3DInputHandler, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_activeInputHandler, doc_QtDataVisualization_QAbstract3DGraph_activeInputHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_shadowsSupported, "shadowsSupported(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_shadowsSupported(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_shadowsSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::shadowsSupported() : sipCpp->shadowsSupported());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_shadowsSupported, doc_QtDataVisualization_QAbstract3DGraph_shadowsSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_event, "event(self, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_event(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_event, doc_QtDataVisualization_QAbstract3DGraph_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_resizeEvent, "resizeEvent(self, event: QResizeEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_resizeEvent, doc_QtDataVisualization_QAbstract3DGraph_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_exposeEvent, "exposeEvent(self, event: QExposeEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_exposeEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_exposeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QExposeEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QExposeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::exposeEvent(a0) : sipCpp->exposeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_exposeEvent, doc_QtDataVisualization_QAbstract3DGraph_exposeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_mouseDoubleClickEvent, doc_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_touchEvent, "touchEvent(self, event: QTouchEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_touchEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_touchEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTouchEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QTouchEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::touchEvent(a0) : sipCpp->touchEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_touchEvent, doc_QtDataVisualization_QAbstract3DGraph_touchEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_mousePressEvent, "mousePressEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_mousePressEvent, doc_QtDataVisualization_QAbstract3DGraph_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent, "mouseReleaseEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_mouseReleaseEvent, doc_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent, "mouseMoveEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_mouseMoveEvent, doc_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_wheelEvent, "wheelEvent(self, event: QWheelEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QAbstract3DGraph::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_wheelEvent, doc_QtDataVisualization_QAbstract3DGraph_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_addCustomItem, "addCustomItem(self, item: QCustom3DItem|None) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addCustomItem(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_addCustomItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QCustom3DItem* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QCustom3DItem, &a0))
        {
            int sipRes;

            sipRes = sipCpp->addCustomItem(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_addCustomItem, doc_QtDataVisualization_QAbstract3DGraph_addCustomItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_removeCustomItems, "removeCustomItems(self)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItems(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            sipCpp->removeCustomItems();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_removeCustomItems, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_removeCustomItem, "removeCustomItem(self, item: QCustom3DItem|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItem(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QCustom3DItem* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QCustom3DItem, &a0))
        {
            sipCpp->removeCustomItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_removeCustomItem, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt, "removeCustomItemAt(self, position: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->removeCustomItemAt(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_removeCustomItemAt, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_releaseCustomItem, "releaseCustomItem(self, item: QCustom3DItem|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseCustomItem(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_releaseCustomItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QCustom3DItem* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QCustom3DItem, &a0))
        {
            sipCpp->releaseCustomItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_releaseCustomItem, doc_QtDataVisualization_QAbstract3DGraph_releaseCustomItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex, "selectedLabelIndex(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->selectedLabelIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectedLabelIndex, doc_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectedAxis, "selectedAxis(self) -> QAbstract3DAxis|None");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedAxis(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DAxis*sipRes;

            sipRes = sipCpp->selectedAxis();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QAbstract3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectedAxis, doc_QtDataVisualization_QAbstract3DGraph_selectedAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex, "selectedCustomItemIndex(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->selectedCustomItemIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectedCustomItemIndex, doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItem, "selectedCustomItem(self) -> QCustom3DItem|None");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItem(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QCustom3DItem*sipRes;

            sipRes = sipCpp->selectedCustomItem();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QCustom3DItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectedCustomItem, doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_renderToImage, "renderToImage(self, msaaSamples: int = 0, imageSize: QSize = QSize()) -> QImage");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_renderToImage(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_renderToImage(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 0;
        const ::QSize& a1def = QSize();
        const ::QSize* a1 = &a1def;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msaaSamples,
            sipName_imageSize,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|iJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0, sipType_QSize, &a1))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->renderToImage(a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_renderToImage, doc_QtDataVisualization_QAbstract3DGraph_renderToImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setMeasureFps, "setMeasureFps(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setMeasureFps(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setMeasureFps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setMeasureFps(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setMeasureFps, doc_QtDataVisualization_QAbstract3DGraph_setMeasureFps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_measureFps, "measureFps(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_measureFps(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_measureFps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->measureFps();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_measureFps, doc_QtDataVisualization_QAbstract3DGraph_measureFps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_currentFps, "currentFps(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_currentFps(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_currentFps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->currentFps();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_currentFps, doc_QtDataVisualization_QAbstract3DGraph_currentFps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setOrthoProjection, "setOrthoProjection(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setOrthoProjection(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setOrthoProjection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setOrthoProjection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setOrthoProjection, doc_QtDataVisualization_QAbstract3DGraph_setOrthoProjection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_isOrthoProjection, "isOrthoProjection(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isOrthoProjection(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isOrthoProjection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isOrthoProjection();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_isOrthoProjection, doc_QtDataVisualization_QAbstract3DGraph_isOrthoProjection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_selectedElement, "selectedElement(self) -> QAbstract3DGraph.ElementType");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedElement(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_selectedElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DGraph::ElementType sipRes;

            sipRes = sipCpp->selectedElement();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DGraph_ElementType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_selectedElement, doc_QtDataVisualization_QAbstract3DGraph_selectedElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setAspectRatio, "setAspectRatio(self, ratio: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setAspectRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setAspectRatio, doc_QtDataVisualization_QAbstract3DGraph_setAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_aspectRatio, "aspectRatio(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_aspectRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_aspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->aspectRatio();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_aspectRatio, doc_QtDataVisualization_QAbstract3DGraph_aspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setOptimizationHints, "setOptimizationHints(self, hints: QAbstract3DGraph.OptimizationHints|QAbstract3DGraph.OptimizationHint)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setOptimizationHints(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setOptimizationHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph::OptimizationHints* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, &a0, &a0State))
        {
            sipCpp->setOptimizationHints(*a0);
            sipReleaseType(a0, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setOptimizationHints, doc_QtDataVisualization_QAbstract3DGraph_setOptimizationHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_optimizationHints, "optimizationHints(self) -> QAbstract3DGraph.OptimizationHints");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_optimizationHints(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_optimizationHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DGraph::OptimizationHints*sipRes;

            sipRes = new ::QtDataVisualization::QAbstract3DGraph::OptimizationHints(sipCpp->optimizationHints());

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_optimizationHints, doc_QtDataVisualization_QAbstract3DGraph_optimizationHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_customItems, "customItems(self) -> list[QCustom3DItem]");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_customItems(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_customItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            QList< ::QtDataVisualization::QCustom3DItem*>*sipRes;

            sipRes = new QList< ::QtDataVisualization::QCustom3DItem*>(sipCpp->customItems());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtDataVisualization_QCustom3DItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_customItems, doc_QtDataVisualization_QAbstract3DGraph_customItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setPolar, "setPolar(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setPolar(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setPolar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setPolar(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setPolar, doc_QtDataVisualization_QAbstract3DGraph_setPolar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_isPolar, "isPolar(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isPolar(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isPolar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPolar();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_isPolar, doc_QtDataVisualization_QAbstract3DGraph_isPolar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset, "setRadialLabelOffset(self, offset: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setRadialLabelOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setRadialLabelOffset, doc_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_radialLabelOffset, "radialLabelOffset(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_radialLabelOffset(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_radialLabelOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->radialLabelOffset();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_radialLabelOffset, doc_QtDataVisualization_QAbstract3DGraph_radialLabelOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio, "setHorizontalAspectRatio(self, ratio: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setHorizontalAspectRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setHorizontalAspectRatio, doc_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio, "horizontalAspectRatio(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->horizontalAspectRatio();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_horizontalAspectRatio, doc_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setReflection, "setReflection(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setReflection(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setReflection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setReflection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setReflection, doc_QtDataVisualization_QAbstract3DGraph_setReflection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_isReflection, "isReflection(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isReflection(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_isReflection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReflection();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_isReflection, doc_QtDataVisualization_QAbstract3DGraph_isReflection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setReflectivity, "setReflectivity(self, reflectivity: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setReflectivity(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setReflectivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setReflectivity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setReflectivity, doc_QtDataVisualization_QAbstract3DGraph_setReflectivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_reflectivity, "reflectivity(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_reflectivity(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_reflectivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->reflectivity();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_reflectivity, doc_QtDataVisualization_QAbstract3DGraph_reflectivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setLocale, doc_QtDataVisualization_QAbstract3DGraph_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_locale(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_locale, doc_QtDataVisualization_QAbstract3DGraph_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition, "queriedGraphPosition(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->queriedGraphPosition());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_queriedGraphPosition, doc_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_setMargin, "setMargin(self, margin: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setMargin(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_setMargin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp, &a0))
        {
            sipCpp->setMargin(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_setMargin, doc_QtDataVisualization_QAbstract3DGraph_setMargin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_margin, "margin(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_margin(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_margin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->margin();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_margin, doc_QtDataVisualization_QAbstract3DGraph_margin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DGraph_hasContext, "hasContext(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DGraph_hasContext(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DGraph_hasContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DGraph *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DGraph, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasContext();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DGraph, sipName_hasContext, doc_QtDataVisualization_QAbstract3DGraph_hasContext);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QAbstract3DGraph(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QAbstract3DGraph(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QAbstract3DGraph *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DGraph *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QAbstract3DGraph)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWindow)->ctd_cast(static_cast< ::QWindow *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QAbstract3DGraph(void *, int);}
static void release_QtDataVisualization_QAbstract3DGraph(void *sipCppV, int)
{
    ::QtDataVisualization::QAbstract3DGraph *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DGraph *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtDataVisualization_QAbstract3DGraph(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QAbstract3DGraph(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QAbstract3DGraph(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QAbstract3DGraph[] = {{23, 1, 1}};


static PyMethodDef methods_QtDataVisualization_QAbstract3DGraph[] = {
    {sipName_activeInputHandler, meth_QtDataVisualization_QAbstract3DGraph_activeInputHandler, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_activeInputHandler},
    {sipName_activeTheme, meth_QtDataVisualization_QAbstract3DGraph_activeTheme, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_activeTheme},
    {sipName_addCustomItem, meth_QtDataVisualization_QAbstract3DGraph_addCustomItem, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_addCustomItem},
    {sipName_addInputHandler, meth_QtDataVisualization_QAbstract3DGraph_addInputHandler, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_addInputHandler},
    {sipName_addTheme, meth_QtDataVisualization_QAbstract3DGraph_addTheme, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_addTheme},
    {sipName_aspectRatio, meth_QtDataVisualization_QAbstract3DGraph_aspectRatio, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_aspectRatio},
    {sipName_clearSelection, meth_QtDataVisualization_QAbstract3DGraph_clearSelection, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_clearSelection},
    {sipName_currentFps, meth_QtDataVisualization_QAbstract3DGraph_currentFps, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_currentFps},
    {sipName_customItems, meth_QtDataVisualization_QAbstract3DGraph_customItems, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_customItems},
    {sipName_event, meth_QtDataVisualization_QAbstract3DGraph_event, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_event},
    {sipName_exposeEvent, meth_QtDataVisualization_QAbstract3DGraph_exposeEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_exposeEvent},
    {sipName_hasContext, meth_QtDataVisualization_QAbstract3DGraph_hasContext, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_hasContext},
    {sipName_horizontalAspectRatio, meth_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_horizontalAspectRatio},
    {sipName_inputHandlers, meth_QtDataVisualization_QAbstract3DGraph_inputHandlers, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_inputHandlers},
    {sipName_isOrthoProjection, meth_QtDataVisualization_QAbstract3DGraph_isOrthoProjection, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_isOrthoProjection},
    {sipName_isPolar, meth_QtDataVisualization_QAbstract3DGraph_isPolar, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_isPolar},
    {sipName_isReflection, meth_QtDataVisualization_QAbstract3DGraph_isReflection, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_isReflection},
    {sipName_locale, meth_QtDataVisualization_QAbstract3DGraph_locale, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_locale},
    {sipName_margin, meth_QtDataVisualization_QAbstract3DGraph_margin, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_margin},
    {sipName_measureFps, meth_QtDataVisualization_QAbstract3DGraph_measureFps, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_measureFps},
    {sipName_mouseDoubleClickEvent, meth_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QtDataVisualization_QAbstract3DGraph_mousePressEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_mouseReleaseEvent},
    {sipName_optimizationHints, meth_QtDataVisualization_QAbstract3DGraph_optimizationHints, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_optimizationHints},
    {sipName_queriedGraphPosition, meth_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_queriedGraphPosition},
    {sipName_radialLabelOffset, meth_QtDataVisualization_QAbstract3DGraph_radialLabelOffset, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_radialLabelOffset},
    {sipName_reflectivity, meth_QtDataVisualization_QAbstract3DGraph_reflectivity, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_reflectivity},
    {sipName_releaseCustomItem, meth_QtDataVisualization_QAbstract3DGraph_releaseCustomItem, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_releaseCustomItem},
    {sipName_releaseInputHandler, meth_QtDataVisualization_QAbstract3DGraph_releaseInputHandler, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_releaseInputHandler},
    {sipName_releaseTheme, meth_QtDataVisualization_QAbstract3DGraph_releaseTheme, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_releaseTheme},
    {sipName_removeCustomItem, meth_QtDataVisualization_QAbstract3DGraph_removeCustomItem, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItem},
    {sipName_removeCustomItemAt, meth_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItemAt},
    {sipName_removeCustomItems, meth_QtDataVisualization_QAbstract3DGraph_removeCustomItems, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_removeCustomItems},
    {sipName_renderToImage, SIP_MLMETH_CAST(meth_QtDataVisualization_QAbstract3DGraph_renderToImage), METH_VARARGS|METH_KEYWORDS, doc_QtDataVisualization_QAbstract3DGraph_renderToImage},
    {sipName_resizeEvent, meth_QtDataVisualization_QAbstract3DGraph_resizeEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_resizeEvent},
    {sipName_scene, meth_QtDataVisualization_QAbstract3DGraph_scene, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_scene},
    {sipName_selectedAxis, meth_QtDataVisualization_QAbstract3DGraph_selectedAxis, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectedAxis},
    {sipName_selectedCustomItem, meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItem, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItem},
    {sipName_selectedCustomItemIndex, meth_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectedCustomItemIndex},
    {sipName_selectedElement, meth_QtDataVisualization_QAbstract3DGraph_selectedElement, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectedElement},
    {sipName_selectedLabelIndex, meth_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectedLabelIndex},
    {sipName_selectionMode, meth_QtDataVisualization_QAbstract3DGraph_selectionMode, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_selectionMode},
    {sipName_setActiveInputHandler, meth_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setActiveInputHandler},
    {sipName_setActiveTheme, meth_QtDataVisualization_QAbstract3DGraph_setActiveTheme, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setActiveTheme},
    {sipName_setAspectRatio, meth_QtDataVisualization_QAbstract3DGraph_setAspectRatio, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setAspectRatio},
    {sipName_setHorizontalAspectRatio, meth_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setHorizontalAspectRatio},
    {sipName_setLocale, meth_QtDataVisualization_QAbstract3DGraph_setLocale, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setLocale},
    {sipName_setMargin, meth_QtDataVisualization_QAbstract3DGraph_setMargin, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setMargin},
    {sipName_setMeasureFps, meth_QtDataVisualization_QAbstract3DGraph_setMeasureFps, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setMeasureFps},
    {sipName_setOptimizationHints, meth_QtDataVisualization_QAbstract3DGraph_setOptimizationHints, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setOptimizationHints},
    {sipName_setOrthoProjection, meth_QtDataVisualization_QAbstract3DGraph_setOrthoProjection, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setOrthoProjection},
    {sipName_setPolar, meth_QtDataVisualization_QAbstract3DGraph_setPolar, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setPolar},
    {sipName_setRadialLabelOffset, meth_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setRadialLabelOffset},
    {sipName_setReflection, meth_QtDataVisualization_QAbstract3DGraph_setReflection, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setReflection},
    {sipName_setReflectivity, meth_QtDataVisualization_QAbstract3DGraph_setReflectivity, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setReflectivity},
    {sipName_setSelectionMode, meth_QtDataVisualization_QAbstract3DGraph_setSelectionMode, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setSelectionMode},
    {sipName_setShadowQuality, meth_QtDataVisualization_QAbstract3DGraph_setShadowQuality, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_setShadowQuality},
    {sipName_shadowQuality, meth_QtDataVisualization_QAbstract3DGraph_shadowQuality, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_shadowQuality},
    {sipName_shadowsSupported, meth_QtDataVisualization_QAbstract3DGraph_shadowsSupported, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_shadowsSupported},
    {sipName_themes, meth_QtDataVisualization_QAbstract3DGraph_themes, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_themes},
    {sipName_touchEvent, meth_QtDataVisualization_QAbstract3DGraph_touchEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_touchEvent},
    {sipName_wheelEvent, meth_QtDataVisualization_QAbstract3DGraph_wheelEvent, METH_VARARGS, doc_QtDataVisualization_QAbstract3DGraph_wheelEvent}
};

static sipEnumMemberDef enummembers_QtDataVisualization_QAbstract3DGraph[] = {
    {sipName_ElementAxisXLabel, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementAxisXLabel), 33},
    {sipName_ElementAxisYLabel, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementAxisYLabel), 33},
    {sipName_ElementAxisZLabel, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementAxisZLabel), 33},
    {sipName_ElementCustomItem, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementCustomItem), 33},
    {sipName_ElementNone, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementNone), 33},
    {sipName_ElementSeries, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ElementSeries), 33},
    {sipName_OptimizationDefault, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::OptimizationDefault), 34},
    {sipName_OptimizationStatic, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::OptimizationStatic), 34},
    {sipName_SelectionColumn, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionColumn), 36},
    {sipName_SelectionItem, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionItem), 36},
    {sipName_SelectionItemAndColumn, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionItemAndColumn), 36},
    {sipName_SelectionItemAndRow, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionItemAndRow), 36},
    {sipName_SelectionItemRowAndColumn, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionItemRowAndColumn), 36},
    {sipName_SelectionMultiSeries, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionMultiSeries), 36},
    {sipName_SelectionNone, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionNone), 36},
    {sipName_SelectionRow, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionRow), 36},
    {sipName_SelectionRowAndColumn, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionRowAndColumn), 36},
    {sipName_SelectionSlice, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::SelectionSlice), 36},
    {sipName_ShadowQualityHigh, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualityHigh), 38},
    {sipName_ShadowQualityLow, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualityLow), 38},
    {sipName_ShadowQualityMedium, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualityMedium), 38},
    {sipName_ShadowQualityNone, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualityNone), 38},
    {sipName_ShadowQualitySoftHigh, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualitySoftHigh), 38},
    {sipName_ShadowQualitySoftLow, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualitySoftLow), 38},
    {sipName_ShadowQualitySoftMedium, static_cast<int>(::QtDataVisualization::QAbstract3DGraph::ShadowQualitySoftMedium), 38},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QAbstract3DGraph[] = {
    {"marginChanged(qreal)", "\1marginChanged(self, margin: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"queriedGraphPositionChanged(QVector3D)", "\1queriedGraphPositionChanged(self, data: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"localeChanged(QLocale)", "\1localeChanged(self, locale: QLocale)", SIP_NULLPTR, SIP_NULLPTR},
    {"reflectivityChanged(qreal)", "\1reflectivityChanged(self, reflectivity: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"reflectionChanged(bool)", "\1reflectionChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"horizontalAspectRatioChanged(qreal)", "\1horizontalAspectRatioChanged(self, ratio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"radialLabelOffsetChanged(float)", "\1radialLabelOffsetChanged(self, offset: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"polarChanged(bool)", "\1polarChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"optimizationHintsChanged(QAbstract3DGraph::OptimizationHints)|(QtDataVisualization::QAbstract3DGraph::OptimizationHints)", "\1optimizationHintsChanged(self, hints: QAbstract3DGraph.OptimizationHints|QAbstract3DGraph.OptimizationHint)", SIP_NULLPTR, SIP_NULLPTR},
    {"aspectRatioChanged(qreal)", "\1aspectRatioChanged(self, ratio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"orthoProjectionChanged(bool)", "\1orthoProjectionChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentFpsChanged(qreal)", "\1currentFpsChanged(self, fps: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"measureFpsChanged(bool)", "\1measureFpsChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectedElementChanged(QAbstract3DGraph::ElementType)|(QtDataVisualization::QAbstract3DGraph::ElementType)", "\1selectedElementChanged(self, type: QAbstract3DGraph.ElementType)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadowQualityChanged(QAbstract3DGraph::ShadowQuality)|(QtDataVisualization::QAbstract3DGraph::ShadowQuality)", "\1shadowQualityChanged(self, quality: QAbstract3DGraph.ShadowQuality)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectionModeChanged(QAbstract3DGraph::SelectionFlags)|(QtDataVisualization::QAbstract3DGraph::SelectionFlags)", "\1selectionModeChanged(self, mode: QAbstract3DGraph.SelectionFlags|QAbstract3DGraph.SelectionFlag)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeThemeChanged(Q3DTheme*)|(QtDataVisualization::Q3DTheme*)", "\1activeThemeChanged(self, theme: Q3DTheme|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeInputHandlerChanged(QAbstract3DInputHandler*)|(QtDataVisualization::QAbstract3DInputHandler*)", "\1activeInputHandlerChanged(self, inputHandler: QAbstract3DInputHandler|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QAbstract3DGraph = {
    &::QtDataVisualization::QAbstract3DGraph::staticMetaObject,
    0,
    signals_QtDataVisualization_QAbstract3DGraph,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QAbstract3DGraph,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QAbstract3DGraph,
    },
    {
        sipNameNr_QAbstract3DGraph,
        {0, 0, 1},
        63, methods_QtDataVisualization_QAbstract3DGraph,
        25, enummembers_QtDataVisualization_QAbstract3DGraph,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtDataVisualization_QAbstract3DGraph,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QAbstract3DGraph,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtDataVisualization_QAbstract3DGraph,
    cast_QtDataVisualization_QAbstract3DGraph,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
